@@ -1,4 +1,4 @@
-#' Gradient scales from WhiteboxTools color schemes
+#' Gradient scales from **WhiteboxTools** color schemes
 #'
 #' @description
 #'
@@ -14,22 +14,22 @@
 #'
 #'
 #' Additional parameters `...` would be passed on to:
-#' - Discrete values: [ggplot2::discrete_scale()]
-#' - Continuous values: [ggplot2::continuous_scale()]
+#' - Discrete values: [ggplot2::discrete_scale()].
+#' - Continuous values: [ggplot2::continuous_scale()].
 #' - Binned continuous values: [ggplot2::binned_scale()].
 #'
-#' Note that \pkg{tidyterra} just documents a selection of these additional
-#' parameters, check the previous links to see the full range of parameters
-#' accepted by these scales.
+#' **Note that** \CRANpkg{tidyterra} just documents a selection of these
+#' additional parameters, check the \CRANpkg{ggplot2} functions listed above to
+#' see the full range of parameters accepted by these scales.
 #'
 #' @export
 #'
 #' @name scale_whitebox
 #'
 #' @inheritDotParams ggplot2::discrete_scale breaks:drop
-#' @inheritDotParams ggplot2::continuous_scale breaks:labels na.value
+#' @inheritDotParams ggplot2::continuous_scale breaks:labels
 #' @inheritDotParams ggplot2::binned_scale breaks:limits nice.breaks
-#' @inheritParams ggplot2::scale_fill_viridis_b
+#' @inheritParams scale_cross_blended
 #' @param palette A valid palette name. The name is matched to the list of
 #'   available palettes, ignoring upper vs. lower case. Values available are:
 #'
@@ -48,13 +48,14 @@
 #'
 #' @seealso [terra::plot()], [ggplot2::scale_fill_viridis_c()]
 #'
-#' See also \pkg{ggplot2} docs on additional `...` parameters:
+#' See also \CRANpkg{ggplot2} docs on additional `...` parameters:
 #'
 #' - `scale_*_terrain_d()`: For discrete values.
 #' - `scale_*_terrain_c()`: For continuous values.
 #' - `scale_*_terrain_b()`: For binning continuous values.
 #'
-#' @return The corresponding ggplot2 layer with the values applied to the
+#' @return
+#' The corresponding \CRANpkg{ggplot2} layer with the values applied to the
 #' `fill/colour` aesthetics.
 #'
 #' @family gradients
@@ -97,42 +98,52 @@
 #'   scale_fill_whitebox_d(na.value = "gray10", palette = "soft")
 #' }
 scale_fill_whitebox_d <- function(palette = "high_relief", ...,
-                                  alpha = 1, direction = 1) {
+                                  alpha = 1, direction = 1,
+                                  na.translate = FALSE,
+                                  drop = TRUE) {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::discrete_scale(
     aesthetics = "fill",
-    scale_name = "whitebox_fill_d",
     palette = whitebox_pal(
       alpha = alpha,
       direction = direction,
       palette = palette
     ),
+    na.translate = na.translate,
+    drop = drop,
     ...
   )
 }
 #' @export
 #' @rdname scale_whitebox
 scale_colour_whitebox_d <- function(palette = "high_relief", ...,
-                                    alpha = 1, direction = 1) {
+                                    alpha = 1, direction = 1,
+                                    na.translate = FALSE,
+                                    drop = TRUE) {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::discrete_scale(
     aesthetics = "colour",
-    scale_name = "whitebox_colour_d",
     palette = whitebox_pal(
       alpha = alpha,
       direction = direction,
       palette = palette
     ),
+    na.translate = na.translate,
+    drop = drop,
     ...
   )
 }
@@ -141,19 +152,21 @@ scale_colour_whitebox_d <- function(palette = "high_relief", ...,
 #' @rdname scale_whitebox
 scale_fill_whitebox_c <- function(palette = "high_relief", ...,
                                   alpha = 1, direction = 1,
-                                  na.value = NA, guide = "colourbar") {
+                                  na.value = "transparent",
+                                  guide = "colourbar") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   length_pal <- nrow(extract_pal(whitebox_coltab, palette = palette))
 
   ggplot2::continuous_scale(
     aesthetics = "fill",
-    scale_name = "whitebox_fill_c",
-    scales::gradient_n_pal(whitebox_pal(
+    palette = scales::gradient_n_pal(whitebox_pal(
       alpha = alpha,
       direction = direction,
       palette = palette
@@ -168,19 +181,21 @@ scale_fill_whitebox_c <- function(palette = "high_relief", ...,
 #' @rdname scale_whitebox
 scale_colour_whitebox_c <- function(palette = "high_relief", ...,
                                     alpha = 1, direction = 1,
-                                    na.value = NA, guide = "colourbar") {
+                                    na.value = "transparent",
+                                    guide = "colourbar") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   length_pal <- nrow(extract_pal(whitebox_coltab, palette = palette))
 
   ggplot2::continuous_scale(
     aesthetics = "colour",
-    scale_name = "whitebox_colour_c",
-    scales::gradient_n_pal(whitebox_pal(
+    palette = scales::gradient_n_pal(whitebox_pal(
       alpha = alpha,
       direction = direction,
       palette = palette
@@ -196,20 +211,22 @@ scale_colour_whitebox_c <- function(palette = "high_relief", ...,
 #' @rdname scale_whitebox
 scale_fill_whitebox_b <- function(palette = "high_relief", ...,
                                   alpha = 1, direction = 1,
-                                  na.value = NA, guide = "coloursteps") {
+                                  na.value = "transparent",
+                                  guide = "coloursteps") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   length_pal <- nrow(extract_pal(whitebox_coltab, palette = palette))
 
 
   ggplot2::binned_scale(
     aesthetics = "fill",
-    scale_name = "whitebox_fill_b",
-    scales::gradient_n_pal(whitebox_pal(
+    palette = scales::gradient_n_pal(whitebox_pal(
       alpha = alpha,
       direction = direction,
       palette = palette
@@ -224,20 +241,22 @@ scale_fill_whitebox_b <- function(palette = "high_relief", ...,
 #' @rdname scale_whitebox
 scale_colour_whitebox_b <- function(palette = "high_relief", ...,
                                     alpha = 1, direction = 1,
-                                    na.value = NA, guide = "coloursteps") {
+                                    na.value = "transparent",
+                                    guide = "coloursteps") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   length_pal <- nrow(extract_pal(whitebox_coltab, palette = palette))
 
 
   ggplot2::binned_scale(
     aesthetics = "colour",
-    scale_name = "whitebox_colour_b",
-    scales::gradient_n_pal(whitebox_pal(
+    palette = scales::gradient_n_pal(whitebox_pal(
       alpha = alpha,
       direction = direction,
       palette = palette
@@ -308,7 +327,7 @@ extract_pal <- function(df, palette) {
   palette <- tolower(palette)
 
   if (!palette %in% df$pal) {
-    stop("'palette' does not match any given palette")
+    cli::cli_abort("{.arg palette} does not match any given palette")
   }
 
   df <- df[df$pal == palette, ]
