@@ -8,21 +8,29 @@ test_that("geom_spatraster several layer with CRS", {
 
   f_v <- system.file("extdata/cyl.gpkg", package = "tidyterra")
   v <- vect(f_v)
-  v <- terra::project(v, "epsg:3857")
+  v <- terra::project(v, "EPSG:3857")
   v_sf <- sf::st_as_sf(v)
 
   # Errors
-  expect_error(ggplot(r) +
-    geom_spatraster())
-  expect_error(ggplot() +
-    geom_spatraster(data = v), regexp = "only works with SpatRaster")
-  expect_error(ggplot() +
-    geom_spatraster(data = 1:3), regexp = "only works with SpatRaster")
+  expect_error(
+    ggplot(r) +
+      geom_spatraster()
+  )
+  expect_snapshot(
+    ggplot() +
+      geom_spatraster(data = v),
+    error = TRUE
+  )
+  expect_snapshot(
+    ggplot() +
+      geom_spatraster(data = 1:3),
+    error = TRUE
+  )
 
   s <- ggplot() +
     geom_spatraster(data = r) +
     coord_cartesian()
-  expect_warning(ggplot_build(s), regexp = "SpatRasters with crs must be")
+  expect_snapshot(end <- ggplot_build(s))
 
   # test with vdiffr
   skip_on_cran()
@@ -34,9 +42,7 @@ test_that("geom_spatraster several layer with CRS", {
   p <- ggplot() +
     geom_spatraster(data = r)
 
-  expect_message(ggplot2::ggplot_build(p),
-    regexp = "Use facet_wrap"
-  )
+  expect_snapshot(end <- ggplot2::ggplot_build(p))
 
 
   vdiffr::expect_doppelganger("crs_01a: regular no facet", p)
@@ -49,15 +55,24 @@ test_that("geom_spatraster several layer with CRS", {
   vdiffr::expect_doppelganger("crs_01b: regular facet", p)
 
   # Scales
-  vdiffr::expect_doppelganger("crs_02: w/scale cont", p +
-    scale_fill_terrain_c())
+  vdiffr::expect_doppelganger(
+    "crs_02: w/scale cont",
+    p +
+      scale_fill_terrain_c()
+  )
 
-  vdiffr::expect_doppelganger("crs_03: w/scale breaks", p +
-    scale_fill_terrain_b())
+  vdiffr::expect_doppelganger(
+    "crs_03: w/scale breaks",
+    p +
+      scale_fill_terrain_b()
+  )
 
   # Using facets
-  vdiffr::expect_doppelganger("crs_04: w/facets", p +
-    facet_wrap(~lyr))
+  vdiffr::expect_doppelganger(
+    "crs_04: w/facets",
+    p +
+      facet_wrap(~lyr)
+  )
 
   # Using aes
   expect_warning(ggplot() +
@@ -99,16 +114,12 @@ test_that("geom_spatraster several layer with CRS", {
 
   r_mix1 <- r %>% mutate(char = paste("c_", round(tavg_05)))
 
-  expect_message(
-    ggplot() +
+  expect_snapshot(
+    p_mix1 <- ggplot() +
       geom_spatraster(data = r_mix1) +
-      facet_wrap(~lyr),
-    "Mixed data classes"
+      facet_wrap(~lyr) +
+      scale_fill_terrain_c()
   )
-  p_mix1 <- ggplot() +
-    geom_spatraster(data = r_mix1) +
-    facet_wrap(~lyr) +
-    scale_fill_terrain_c()
 
   vdiffr::expect_doppelganger("crs_06b: Mixed with nums", p_mix1)
 
@@ -119,37 +130,31 @@ test_that("geom_spatraster several layer with CRS", {
     mutate(char2 = paste("c_", round(tavg_06))) %>%
     select(char, char2, tavg_04)
 
-  expect_message(
-    ggplot() +
+  expect_snapshot(
+    p_mix2 <- ggplot() +
       geom_spatraster(data = r_mix2) +
-      facet_wrap(~lyr),
-    "Mixed data classes"
+      facet_wrap(~lyr) +
+      scale_fill_terrain_d()
   )
-  p_mix2 <- ggplot() +
-    geom_spatraster(data = r_mix2) +
-    facet_wrap(~lyr) +
-    scale_fill_terrain_d()
-
   vdiffr::expect_doppelganger("crs_06c: Mixed with chars", p_mix2)
 
   # Resampling
 
-  expect_message(ggplot() +
-    geom_spatraster(data = r, maxcell = 20), regexp = "resampled")
-
-  p_res <- ggplot() +
-    geom_spatraster(data = r, maxcell = 20) +
-    facet_wrap(~lyr)
+  expect_snapshot(
+    p_res <- ggplot() +
+      geom_spatraster(data = r, maxcell = 20) +
+      facet_wrap(~lyr)
+  )
 
 
   vdiffr::expect_doppelganger("crs_07: resampled", p_res)
 
   # Resampling and interpolating
-
-  p_res_int <- ggplot() +
-    geom_spatraster(data = r, maxcell = 20, interpolate = TRUE) +
-    facet_wrap(~lyr)
-
+  expect_snapshot(
+    p_res_int <- ggplot() +
+      geom_spatraster(data = r, maxcell = 20, interpolate = TRUE) +
+      facet_wrap(~lyr)
+  )
 
   vdiffr::expect_doppelganger("crs_08: resampled interpolated", p_res_int)
 
@@ -160,18 +165,27 @@ test_that("geom_spatraster several layer with CRS", {
     geom_spatraster(data = r) +
     facet_wrap(~lyr)
 
-  vdiffr::expect_doppelganger("crs_09: change crs", p_rast_first +
-    coord_sf(crs = "ESRI:102003"))
+  vdiffr::expect_doppelganger(
+    "crs_09: change crs",
+    p_rast_first +
+      coord_sf(crs = "ESRI:102003")
+  )
 
   # With vector after
-  vdiffr::expect_doppelganger("crs_10: With sf", p_rast_first +
-    geom_sf(data = v_sf, fill = NA))
+  vdiffr::expect_doppelganger(
+    "crs_10: With sf",
+    p_rast_first +
+      geom_sf(data = v_sf, fill = NA)
+  )
 
   # With vector and crs after
 
-  vdiffr::expect_doppelganger("crs_11: With crs and sf", p_rast_first +
-    geom_sf(data = v_sf, fill = NA) +
-    coord_sf(crs = "ESRI:102003"))
+  vdiffr::expect_doppelganger(
+    "crs_11: With crs and sf",
+    p_rast_first +
+      geom_sf(data = v_sf, fill = NA) +
+      coord_sf(crs = "ESRI:102003")
+  )
 
   # With vector first
   p_sf_first <- ggplot(v_sf) +
@@ -183,8 +197,11 @@ test_that("geom_spatraster several layer with CRS", {
 
   # With vector first and change proj
 
-  vdiffr::expect_doppelganger("crs_13: With sf first and crs", p_sf_first +
-    coord_sf(crs = "ESRI:102003"))
+  vdiffr::expect_doppelganger(
+    "crs_13: With sf first and crs",
+    p_sf_first +
+      coord_sf(crs = "ESRI:102003")
+  )
 
 
   # Suppress colors
@@ -222,7 +239,7 @@ test_that("geom_spatraster several layer with no CRS", {
 
   f_v <- system.file("extdata/cyl.gpkg", package = "tidyterra")
   v <- vect(f_v)
-  v <- terra::project(v, "epsg:3857")
+  v <- terra::project(v, "EPSG:3857")
   v_sf <- sf::st_as_sf(v)
 
   # Remove CRS and save initial
@@ -231,13 +248,10 @@ test_that("geom_spatraster several layer with no CRS", {
   terra::crs(r) <- NA
 
   # Errors
-  expect_error(ggplot(r) +
-    geom_spatraster())
-  expect_error(ggplot() +
-    geom_spatraster(data = v), regexp = "only works with SpatRaster")
-  expect_error(ggplot() +
-    geom_spatraster(data = 1:3), regexp = "only works with SpatRaster")
-
+  expect_error(
+    ggplot(r) +
+      geom_spatraster()
+  )
   s <- ggplot() +
     geom_spatraster(data = r) +
     facet_wrap(~lyr) +
@@ -254,10 +268,7 @@ test_that("geom_spatraster several layer with no CRS", {
   p <- ggplot() +
     geom_spatraster(data = r)
 
-  expect_message(ggplot2::ggplot_build(p),
-    regexp = "Use facet_wrap"
-  )
-
+  expect_snapshot(expect_message(ggplot2::ggplot_build(p)))
 
   vdiffr::expect_doppelganger("nocrs_01a: regular no facet", p)
 
@@ -271,20 +282,32 @@ test_that("geom_spatraster several layer with no CRS", {
 
   # Change coords
 
-  vdiffr::expect_doppelganger("nocrs_01c: regular facet with coords", p +
-    coord_equal())
+  vdiffr::expect_doppelganger(
+    "nocrs_01c: regular facet with coords",
+    p +
+      coord_equal()
+  )
 
 
   # Scales
-  vdiffr::expect_doppelganger("nocrs_02: w/scale cont", p +
-    scale_fill_terrain_c())
+  vdiffr::expect_doppelganger(
+    "nocrs_02: w/scale cont",
+    p +
+      scale_fill_terrain_c()
+  )
 
-  vdiffr::expect_doppelganger("nocrs_03: w/scale breaks", p +
-    scale_fill_terrain_b())
+  vdiffr::expect_doppelganger(
+    "nocrs_03: w/scale breaks",
+    p +
+      scale_fill_terrain_b()
+  )
 
   # Using facets
-  vdiffr::expect_doppelganger("nocrs_04: w/facets", p +
-    facet_wrap(~lyr))
+  vdiffr::expect_doppelganger(
+    "nocrs_04: w/facets",
+    p +
+      facet_wrap(~lyr)
+  )
 
   # Using aes
   expect_warning(ggplot() +
@@ -326,17 +349,12 @@ test_that("geom_spatraster several layer with no CRS", {
 
   r_mix1 <- r %>% mutate(char = paste("c_", round(tavg_05)))
 
-  expect_message(
-    ggplot() +
+  expect_snapshot(
+    p_mix1 <- ggplot() +
       geom_spatraster(data = r_mix1) +
-      facet_wrap(~lyr),
-    "Mixed data classes"
+      facet_wrap(~lyr) +
+      scale_fill_terrain_c()
   )
-  p_mix1 <- ggplot() +
-    geom_spatraster(data = r_mix1) +
-    facet_wrap(~lyr) +
-    scale_fill_terrain_c()
-
   vdiffr::expect_doppelganger("nocrs_06b: Mixed with nums", p_mix1)
 
 
@@ -346,27 +364,26 @@ test_that("geom_spatraster several layer with no CRS", {
     mutate(char2 = paste("c_", round(tavg_06))) %>%
     select(char, char2, tavg_04)
 
-  expect_message(
-    ggplot() +
+  expect_snapshot(
+    p_mix2 <- ggplot() +
       geom_spatraster(data = r_mix2) +
-      facet_wrap(~lyr),
-    "Mixed data classes"
+      facet_wrap(~lyr) +
+      scale_fill_terrain_d()
   )
-  p_mix2 <- ggplot() +
-    geom_spatraster(data = r_mix2) +
-    facet_wrap(~lyr) +
-    scale_fill_terrain_d()
-
   vdiffr::expect_doppelganger("nocrs_06c: Mixed with chars", p_mix2)
 
   # Resampling
 
-  expect_message(ggplot() +
-    geom_spatraster(data = r, maxcell = 20), regexp = "resampled")
+  expect_message(
+    ggplot() +
+      geom_spatraster(data = r, maxcell = 20)
+  )
 
-  p_res <- ggplot() +
-    geom_spatraster(data = r, maxcell = 20) +
-    facet_wrap(~lyr)
+  expect_snapshot(
+    p_res <- ggplot() +
+      geom_spatraster(data = r, maxcell = 20) +
+      facet_wrap(~lyr)
+  )
 
 
   vdiffr::expect_doppelganger("nocrs_07: resampled", p_res)
@@ -387,25 +404,37 @@ test_that("geom_spatraster several layer with no CRS", {
     geom_spatraster(data = r) +
     facet_wrap(~lyr)
 
-  vdiffr::expect_doppelganger("nocrs_09: change crs", p_rast_first +
-    coord_sf(crs = raster_crs))
+  vdiffr::expect_doppelganger(
+    "nocrs_09: change crs",
+    p_rast_first +
+      coord_sf(crs = raster_crs)
+  )
 
   # With vector
-  vdiffr::expect_doppelganger("nocrs_10: With sf", p_rast_first +
-    geom_sf(data = v_sf, fill = NA))
+  vdiffr::expect_doppelganger(
+    "nocrs_10: With sf",
+    p_rast_first +
+      geom_sf(data = v_sf, fill = NA)
+  )
 
   # Would align only if sf/coord on the same crs
 
-  vdiffr::expect_doppelganger("nocrs_11: With crs and sf", p_rast_first +
-    geom_sf(data = v_sf, fill = NA) +
-    coord_sf(crs = raster_crs))
+  vdiffr::expect_doppelganger(
+    "nocrs_11: With crs and sf",
+    p_rast_first +
+      geom_sf(data = v_sf, fill = NA) +
+      coord_sf(crs = raster_crs)
+  )
 
   # Reproject vector
 
   new_v <- sf::st_transform(v_sf, raster_crs)
 
-  vdiffr::expect_doppelganger("nocrs_12: With sf reprojected", p_rast_first +
-    geom_sf(data = new_v, fill = NA))
+  vdiffr::expect_doppelganger(
+    "nocrs_12: With sf reprojected",
+    p_rast_first +
+      geom_sf(data = new_v, fill = NA)
+  )
 
   # Suppress colors
   r2 <- r / 100
